@@ -10,13 +10,11 @@
 #include <QCommandLineParser>
 #include <QCoreApplication>
 #include <QDate>
-#include <QFile>
 #include <QFutureWatcher>
 #include <QMutexLocker>
 #include <QProcess>
-#include <QStandardPaths>
 #include <QTextStream>
-#include <QtConcurrentRun>
+#include <QtConcurrent>
 
 #include <QDebug>
 
@@ -1581,5 +1579,3 @@ int main(int argc, char **argv)
 
     return app.exec();
 }
-
-#include "moc_generator.cpp"
